lilypondfiletools.ContextBlock
==============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock

.. autoclass:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.accepts
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.override
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.set
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.context_name
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.is_formatted_when_empty
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.name
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.type
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.ContextBlock.__setslice__
   :noindex:
